"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateDto = void 0;
function validateDto(dto, dtoType) {
    const constrainedKeys = Reflect.getMetadata("dto:validation", dtoType.prototype);
    if (!constrainedKeys)
        return true;
    const isNotValid = Object.getOwnPropertyNames(constrainedKeys).some(constraint => {
        const key = constrainedKeys[constraint];
        const value = dto[key.name];
        if (!value && key.required)
            return true;
        else if (value) {
            const dtoTypeMod = typeof value === "object" ? (Array.isArray(value) ? "array" : typeof value) : typeof value;
            if (key.checkType && dtoTypeMod !== key.type.toLowerCase()) {
                return true;
            }
            if (key.maxLength && value.length > key.maxLength) {
                return true;
            }
            if (key.minLength && value.length < key.minLength) {
                return true;
            }
            if (key.type === "number" && key.range) {
                if (value < key.range[0] || value > key.range[1])
                    return true;
            }
        }
        return false;
    });
    if (isNotValid)
        return false;
    else
        return true;
}
exports.validateDto = validateDto;
//# sourceMappingURL=validateDto.js.map